@@ -5,6 +5,13 @@
 
 cp /usr/share/applications/defaults.list /usr/share/applications/defaults.list~
 
+echo "video/quicktime=hildon-mediaplayer.desktop" >> /usr/share/applications/defaults.list
+echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list
+
+echo "" >> /usr/share/applications/defaults.list
+echo "# Catch-all on N900" >> /usr/share/applications/defaults.list
+echo "unknown/unknown=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
+
 echo "" >> /usr/share/applications/defaults.list
 echo "# DBus-Switchboard default associations" >> /usr/share/applications/defaults.list
 echo "application/x-bittorrent=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
@@ -31,9 +38,3 @@ echo "text/dbs-tgz=hildon-dbus-switchboard.desktop" >> /usr/share/applications/d
 echo "text/dbs-xls=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
 echo "text/dbs-vb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
 echo "application/dbs-jar=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
-
-# Catch-all on N900
-echo "unknown/unknown=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
-
-echo "video/quicktime=hildon-mediaplayer.desktop" >> /usr/share/applications/defaults.list
-echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list
\ No newline at end of file
